# Third party licenses

This folder contains the licenses of third-party open-source software that has been redistributed in this project.
Details of included files and modifications can be found in [NOTICE](/NOTICE.md).
